//-------------------------------------------------------------------------------
// COGLOG
//-------------------------------------------------------------------------------

function COGLOG( %text )
{
   // If the tutorial is running, pass all log messages to the tutor.
   if( btnTutorial.enabled )
   {
      dlgTutorial.tutor.getDataBlock().UpdateTutorial( %text );
   }

   %logline = "[COGLOG]" SPC getSimTime() SPC %text;
   echo( %logline );

   // Visualization disabled.
   if( $Client::Viz == false ) return;
   if( !registerLibrary("quatslerp") ) return;

   // Establish a connection with the visualization app.
   if( $Client::VizSocket == 0 ) $Client::VizSocket = ConnectTCP( $Client::VizAddress );

   // Send log data to visualization app.
   SendTCPString( $Client::VizSocket, %logline );
}

function COGLOG_LOCALTIME()
{
   COGLOG( "LOCALTIME:" SPC getLocalTime() );
}

function COGLOG_ROLE( %role, %name )
{
   COGLOG( "ROLE" SPC %role SPC "=" SPC %name );
}

function COGLOG_INFO( %who, %tag, %info )
{
   COGLOG( "INFO" SPC COGLOG_ID(%who) SPC %tag SPC "=" SPC "\"" @ %info @ "\"" );
}

function COGLOG_DESCRIPTION( %who, %other, %text )
{
   COGLOG( "DESCRIPTION" SPC COGLOG_ID(%who) SPC %other SPC "= \"" @ %text @ "\"" );
}

function COGLOG_STATECHANGE( %who, %var, %assign )
{
   COGLOG( "STATECHANGE" SPC COGLOG_ID(%who) SPC %var @ "=" @ "\"" @ %assign @ "\"" );
}

function COGLOG_ACTION( %who, %verb, %target )
{
   if( %target == 0 ) COGLOG( "ACTION" SPC COGLOG_ID(%who) SPC %verb SPC "NULL" );
   else COGLOG( "ACTION" SPC COGLOG_ID(%who) SPC %verb SPC COGLOG_ID(%target) );

   // Visualization disabled.
   if( $Client::Viz == false ) return;
   if( !registerLibrary("quatslerp") ) return;

   // Force system to notice a new logged action immediately when visualization is enabled.
   schedule( 1, 0, COGLOG_STATECHANGE, "NULL", "VIZ_ACTION_COMPLETE", "TRUE" );
}

function COGLOG_SPEECHACT( %who, %text )
{
   COGLOG( "SPEECHACT" SPC COGLOG_ID(%who) SPC "\"" @ %text @ "\"" );
}

function COGLOG_EVENT( %who, %verb, %target )
{
   if( %target == 0 ) COGLOG( "EVENT" SPC COGLOG_ID(%who) SPC %verb SPC %target );
   else COGLOG( "EVENT" SPC COGLOG_ID(%who) SPC %verb SPC COGLOG_ID(%target) );
}

function COGLOG_NAME( %obj )
{
   %name = %obj.getName();
   if( %obj.getClassName() $= "TerrainBlock" ) %name = "dynamic" @ %obj;
   else if( %obj.getClassName() $= "InteriorInstance" ) %name = "dynamic" @ %obj;
   else if( %obj.getDatablock().pronoun != 0 ) %name = %obj.getName();
   else if( %name $= "" ) %name = "dynamic" @ %obj;
   return %name;
}

function COGLOG_CLASS( %obj )
{
   if( %obj.getClassName() $= "TerrainBlock" ) return "(TerrainBlock)";
   if( %obj.getClassName() $= "InteriorInstance" ) return "(InteriorInstance)";
   if( %obj.getDatablock().pronoun != 0 ) return "(Player)";
   if( strstr( strupr(%obj.getDataBlock().getName()), "PLAYER" ) != -1 ) return "(Player)";
   return "(" @ %obj.getDataBlock().getName() @ ")";
}

function COGLOG_ID( %obj )
{
   if( %obj $= "NULL" ) return "NULL";
   return COGLOG_NAME( %obj ) @ COGLOG_CLASS(%obj);
}

function COGLOG_POS( %pos )
{
   return "(" @ %pos @ ")";
}










